pub struct Library { /* private fields */ }Expand description
The Library struct manages a collection of projects in a specified directory.
Implementations
Sourceimpl Library
impl Library
Sourcepub fn new(path: &Path, display_hidden: bool) -> Result<Self, LibraryError>
pub fn new(path: &Path, display_hidden: bool) -> Result<Self, LibraryError>
Makes a new Library instance.
Sourcepub fn collect_projects(
path: &Path,
display_hidden: bool,
) -> Result<IndexMap<String, PathBuf>, LibraryError>
pub fn collect_projects( path: &Path, display_hidden: bool, ) -> Result<IndexMap<String, PathBuf>, LibraryError>
Collects projects from the specified directory path.
Sourcepub fn clone(&self, options: &CloneOptions) -> Result<(), LibraryError>
pub fn clone(&self, options: &CloneOptions) -> Result<(), LibraryError>
Clones a Git repository into the library.
Sourcepub fn create(&mut self, name: &str) -> Result<(), LibraryError>
pub fn create(&mut self, name: &str) -> Result<(), LibraryError>
Creates a new project directory in the library.
Sourcepub fn delete(&mut self, name: &str) -> Result<(), LibraryError>
pub fn delete(&mut self, name: &str) -> Result<(), LibraryError>
Deletes a project directory from the library.
Sourcepub fn contains(&self, name: &str) -> bool
pub fn contains(&self, name: &str) -> bool
Checks if a project with the given name exists in the library.